@@ -22,6 +22,8 @@
 #define _GDM_COMMON_H
 
 #include <glib-unix.h>
+#include <gio/gio.h>
+
 #include <pwd.h>
 #include <errno.h>
 
@@ -49,10 +51,10 @@ gboolean       gdm_get_pwent_for_name    (const char     *name,
 
 gboolean       gdm_clear_close_on_exec_flag (int fd);
 
-const char *   gdm_make_temp_dir         (char    *template);
-
 char          *gdm_generate_random_bytes (gsize          size,
                                           GError       **error);
+gboolean       gdm_get_login_window_session_id (const char  *seat_id,
+                                                char       **session_id);
 gboolean       gdm_goto_login_session    (GError **error);
 
 GPtrArray     *gdm_get_script_environment (const char *username,
@@ -71,6 +73,10 @@ char *        gdm_shell_expand            (const char *str,
                                            GdmExpandVarFunc expand_func,
                                            gpointer user_data);
 
+gboolean      gdm_activate_session_by_id (GDBusConnection *connection,
+                                          const char      *seat_id,
+                                          const char      *session_id);
+
 G_END_DECLS
 
 #endif /* _GDM_COMMON_H */
