@@ -24,7 +24,6 @@
 
 #include <glib-object.h>
 #include <gio/gio.h>
-#include "gdm-slave.h"
 
 G_BEGIN_DECLS
 
@@ -41,6 +40,7 @@ typedef enum {
         GDM_DISPLAY_UNMANAGED = 0,
         GDM_DISPLAY_PREPARED,
         GDM_DISPLAY_MANAGED,
+        GDM_DISPLAY_WAITING_TO_FINISH,
         GDM_DISPLAY_FINISHED,
         GDM_DISPLAY_FAILED,
 } GdmDisplayStatus;
@@ -56,22 +56,8 @@ typedef struct
         GObjectClass   parent_class;
 
         /* methods */
-        gboolean (*create_authority)          (GdmDisplay *display);
-        gboolean (*add_user_authorization)    (GdmDisplay *display,
-                                               const char *username,
-                                               char      **filename,
-                                               GError    **error);
-        gboolean (*remove_user_authorization) (GdmDisplay *display,
-                                               const char *username,
-                                               GError    **error);
-        gboolean (*prepare)                   (GdmDisplay *display);
-        gboolean (*manage)                    (GdmDisplay *display);
-        gboolean (*finish)                    (GdmDisplay *display);
-        gboolean (*unmanage)                  (GdmDisplay *display);
-        void     (*get_timed_login_details)   (GdmDisplay *display,
-                                               gboolean   *enabled,
-                                               char      **username,
-                                               int        *delay);
+        gboolean (*prepare) (GdmDisplay *display);
+        void     (*manage)  (GdmDisplay *self);
 } GdmDisplayClass;
 
 typedef enum
@@ -128,11 +114,6 @@ gboolean            gdm_display_get_seat_id                    (GdmDisplay *disp
 gboolean            gdm_display_is_local                       (GdmDisplay *display,
                                                                 gboolean   *local,
                                                                 GError    **error);
-gboolean            gdm_display_get_timed_login_details        (GdmDisplay *display,
-                                                                gboolean   *enabled,
-                                                                char      **username,
-                                                                int        *delay,
-                                                                GError    **error);
 gboolean            gdm_display_is_initial                     (GdmDisplay  *display,
                                                                 gboolean    *initial,
                                                                 GError     **error);
@@ -151,12 +132,10 @@ gboolean            gdm_display_add_user_authorization         (GdmDisplay *disp
 gboolean            gdm_display_remove_user_authorization      (GdmDisplay *display,
                                                                 const char *username,
                                                                 GError    **error);
-
-void                gdm_display_set_up_greeter_session         (GdmDisplay  *display,
-                                                                char       **username);
 void                gdm_display_start_greeter_session          (GdmDisplay  *display);
 void                gdm_display_stop_greeter_session           (GdmDisplay  *display);
-GdmSlave *          gdm_display_get_slave                      (GdmDisplay  *display);
+
+gboolean            gdm_display_connect                        (GdmDisplay *self);
 
 G_END_DECLS
 
