@@ -121,12 +121,29 @@ build_launch_environment (GdmLaunchEnvironment *launch_environment,
 {
         GHashTable    *hash;
         struct passwd *pwent;
-        static const char * const optional_environment[] = {
-                "LANG", "LANGUAGE", "LC_CTYPE", "LC_NUMERIC", "LC_TIME",
-                "LC_COLLATE", "LC_MONETARY", "LC_MESSAGES", "LC_PAPER",
-                "LC_NAME", "LC_ADDRESS", "LC_TELEPHONE", "LC_MEASUREMENT",
-                "LC_IDENTIFICATION", "LC_ALL", "WINDOWPATH", "XCURSOR_PATH",
-                "XDG_CONFIG_DIRS", NULL
+        static const char *const optional_environment[] = {
+                "GI_TYPELIB_PATH",
+                "LANG",
+                "LANGUAGE",
+                "LC_ADDRESS",
+                "LC_ALL",
+                "LC_COLLATE",
+                "LC_CTYPE",
+                "LC_IDENTIFICATION",
+                "LC_MEASUREMENT",
+                "LC_MESSAGES",
+                "LC_MONETARY",
+                "LC_NAME",
+                "LC_NUMERIC",
+                "LC_PAPER",
+                "LC_TELEPHONE",
+                "LC_TIME",
+                "LD_LIBRARY_PATH",
+                "PATH",
+                "WINDOWPATH",
+                "XCURSOR_PATH",
+                "XDG_CONFIG_DIRS",
+                NULL
         };
         char *system_data_dirs;
         int i;
@@ -201,8 +218,6 @@ build_launch_environment (GdmLaunchEnvironment *launch_environment,
                 g_hash_table_insert (hash, g_strdup ("GDM_SEAT_ID"), g_strdup (seat_id));
         }
 
-        g_hash_table_insert (hash, g_strdup ("PATH"), g_strdup (g_getenv ("PATH")));
-
         g_hash_table_insert (hash, g_strdup ("RUNNING_UNDER_GDM"), g_strdup ("true"));
 
         return hash;
@@ -963,6 +978,7 @@ gdm_create_greeter_launch_environment (const char *display_name,
 GdmLaunchEnvironment *
 gdm_create_initial_setup_launch_environment (const char *display_name,
                                              const char *seat_id,
+                                             const char *session_type,
                                              const char *display_hostname,
                                              gboolean    display_is_local)
 {
@@ -970,7 +986,7 @@ gdm_create_initial_setup_launch_environment (const char *display_name,
                                                  INITIAL_SETUP_USERNAME,
                                                  display_name,
                                                  seat_id,
-                                                 NULL,
+                                                 session_type,
                                                  INITIAL_SETUP_SESSION_MODE,
                                                  display_hostname,
                                                  display_is_local);
